@@ -3,9 +3,8 @@ import os
 
 import urlparse
 
-from urllib import quote # for Python 2.4 compatibility
+from urllib import quote
 from urllib2 import urlopen, URLError
-from pkg_resources import resource_filename
 
 from tiddlyweb.util import write_utf8_file, std_error_message
 
@@ -13,6 +12,11 @@ from tiddlywebplugins.instancer import Instance
 
 from tiddlywebplugins.twimport import recipe_to_urls
 
+try:
+    from pkg_resources import resource_filename
+except ImportError:
+    from tiddlywebplugins.utils import resource_filename
+
 
 def spawn(instance_path, init_config, instance_module):
     """
